@@ -754,6 +754,54 @@ sub num2path {{
     749	=> "broken\/te\:chu\\015\\012\\040nked\;do_clen",
     750	=> "broken\/te\:chu\\015\\012nked\;do_chunked",
     751	=> "broken\/te\:chu\\015\\012nked\;do_clen",
+    752	=> "clen\/close\,clenx0\,content",
+    753	=> "clen\/close\,clenx0\,content\,junk",
+    754	=> "clen\/close\,hexlen\,content",
+    755	=> "clen\/close\,hexlen\,content\,junk",
+    756	=> "clen\/close\,000clen\,content",
+    757	=> "clen\/close\,000clen\,content\,junk",
+    758	=> "clen\/close\,clen\,clen\-empty\,content",
+    759	=> "clen\/close\,clen\,clen\-empty\,content\,junk",
+    760	=> "clen\/close\,clen\-empty\,clen\,content",
+    761	=> "clen\/close\,clen\-empty\,clen\,content\,junk",
+    762	=> "clen\/close\,clen\,clen\-invalid\,content",
+    763	=> "clen\/close\,clen\,clen\-invalid\,content\,junk",
+    764	=> "clen\/close\,clen\-invalid\,clen\,content",
+    765	=> "clen\/close\,clen\-invalid\,clen\,content\,junk",
+    766	=> "clen\/close\,overflow32\,content",
+    767	=> "clen\/close\,overflow32\,content\,junk",
+    768	=> "clen\/close\,huge\,content",
+    769	=> "clen\/close\,big\,content",
+    770	=> "chunked\/huge\-white\-space\-chunked",
+    771	=> "chunked\/emptyte\,chunked\,do_chunked\,gzip",
+    772	=> "chunked\/emptyte\,chunked\,do_clen\,gzip",
+    773	=> "chunked\/chunked\,emptyte\,do_chunked\,gzip",
+    774	=> "chunked\/chunked\,emptyte\,do_clen\,gzip",
+    775	=> "compressed\/ce\:hugespace\-gzip\;gzip",
+    776	=> "compressed\/ce\:hugespace\-deflate\;deflate",
+    777	=> "chunked\/chunked\,clen\-big",
+    778	=> "range\/range\,multi\-full",
+    779	=> "range\/range\,200\,multi\-full",
+    780	=> "compressed\/data\:Content\-Encoding\:\\040\\040\\040\\040\\040\\040\\040\\040\\040\\040\\040br\\r\\n\;brotli",
+    781	=> "compressed\/ce\:gzip\;data\:X\-Foo\:\\n\;ce\:deflate\;gzip\;deflate",
+    782	=> "compressed\/ce\:gzip\;data\:X\-Foo\:\\r\;ce\:deflate\;gzip\;deflate",
+    783	=> "compressed\/ce\:gzip\;ce\:chunked\;gzip",
+    784	=> "compressed\/ce\:chunked\;ce\:gzip\;gzip",
+    785	=> "compressed\/ce\:deflate\;ce\:chunked\;deflate",
+    786	=> "compressed\/ce\:chunked\;ce\:deflate\;deflate",
+    787	=> "compressed\/ce\:deflate\;ce\:identity\;ce\:gzip\;deflate\;gzip",
+    788	=> "compressed\/ce\:gzip\;gzip\;replace\:3\,1\|02\;replace\:10\,0\=0001",
+    789	=> "compressed\/chunked\;ce\:gzip\;gzip\;replace\:3\,1\|20",
+    790	=> "compressed\/chunked\;ce\:gzip\;gzip\;replace\:3\,1\|40",
+    791	=> "compressed\/chunked\;ce\:gzip\;gzip\;replace\:3\,1\|80",
+    792	=> "compressed\/chunked\;ce\:gzip\;gzip\;replace\:\-8\,4\^ffffffff",
+    793	=> "compressed\/chunked\;ce\:gzip\;gzip\;replace\:\-4\,1\^ff",
+    794	=> "compressed\/chunked\;ce\:gzip\;gzip\;replace\:\-4\,4\=",
+    795	=> "compressed\/chunked\;ce\:gzip\;gzip\;replace\:\-8\,8\=",
+    796	=> "compressed\/chunked\;ce\:gzip\;gzip\;replace\:\-4\,4\=\;clen\+4",
+    797	=> "compressed\/chunked\;ce\:gzip\;gzip\;replace\:\-8\,8\=\;clen\+8",
+    798	=> "compressed\/chunked\;ce\:gzip\;gzip\;replace\:\-4\,4\=\;noclen",
+    799	=> "compressed\/chunked\;ce\:gzip\;gzip\;replace\:\-8\,8\=\;noclen",
 
 }};
 
